// Reference: https://bl.ocks.org/zwang155/5079c689233607dd9bdd28d4e39fb290

function main() {
  let xLabels = [
    'Donald Trump',
    'Joe Biden',
  ];
  let svg = d3.select('svg'),
    margin = { top: 60, bottom: 60, left: 60, right: 0 },
    width = 600 - margin.left - margin.right,
    height = 475 - margin.top - margin.bottom;

  
  //Add Scales
  let xScale = d3
      .scaleBand()
      .range([margin.left, margin.left + width])
      .padding(0.25),
    yScale = d3
      .scaleLinear()
      .range([height * 0.29 + margin.top, margin.top]),
    colorScale = d3
      .scaleQuantize()
      .range(colorbrewer.Reds[7]);

  //Add Tooltip
  var div = d3
    .select('body')
    .append('div')
    .attr('class', 'tooltip')
    .style('opacity', 0)
  	.style("font-size", "13px");

  //Decimal number format
  var formatDecimal = d3.format(',.2f');

  //Read Data
  d3.csv('barchart.csv', (d) => {
    return {
      code: d['Candidate'],
      horsepower: +d[
        'Votes'
      ],
    };
  }).then((dataset) => {
    let data = [];
    dataset.forEach((elem) => {
      if (xLabels.includes(elem.code)) {
        data.push(elem);
      }
    });
    data.sort((a, b) => a.horsepower - b.horsepower);
    let xSeq = [];
    data.forEach((elem) => xSeq.push(elem.code));

    xScale.domain(xSeq);
    yScale.domain([0, d3.max(data, (d) => d.horsepower)]);
    colorScale.domain([
      0,
      d3.max(data, (d) => d.horsepower),
    ]);

    //Add Graph
    svg
      .selectAll('rect')
      .data(data)
      .enter()
      .append('rect')
      .attr('x', (d) => xScale(d.code))
      .attr('y', (d) => yScale(d.horsepower))
      .attr('width', xScale.bandwidth())
      .attr(
        'height',
        (d) => height + margin.top - yScale(d.horsepower)
      )
      .attr('fill', (d) => colorScale(d.horsepower))

    //Add Title
    svg
      .append('text')
      .attr('text-anchor', 'middle')
      .attr('x', width / 2 + margin.left)
      .attr('y', margin.top / 3)
    	.text('2020 Election Total Votes in California');

       svg
      .append('text')
      .attr('text-anchor', 'middle')
      .attr('x', width / 3.6 + margin.left)
      .attr('y', margin.top * 1.7)
      .text('6M');
    
       svg
      .append('text')
      .attr('text-anchor', 'middle')
      .attr('x', width / 1.4 + margin.left)
      .attr('y', margin.top * 0.9)
      .text('11M');

    //X Axis
    svg
      .append('g')
      .attr('class', 'axis')
      .attr(
        'transform',
        'translate(0, ' + (height + margin.top) + ')'
      )
      .call(d3.axisBottom(xScale).tickValues(xLabels))
      .append('text')
      .attr('text-anchor', 'middle')
      .attr('x', width / 2 + margin.left)
      .attr('y', margin.bottom / 1.5)     
      .text('Candidates')
    	.style("font-size", "16px");

  });
}

main();
